# RasterMiner

## Installation using Anaconda.

1. Install and set up Anaconda. URL:   https://linuxize.com/post/how-to-install-anaconda-on-centos-7
2. Create a virtual environment using conda. E.g., coda create --name rasterMiner
3. Enter into virtual environment.  E.g., conda activate rasterMiner
4. Install python.   E.g., conda install python
5. Install pycharm from the website
6. Open Pycharm and using VCS download the latest copy of rasterMiner from GitHub
7. In the pycharm, add rasterMiner as the interpreter
8. Open the terminal in pycharm, and execute the following command

          pip install mplcursors matplotlib sklearn pandas
          
